@@ -1,5 +1,5 @@
 import sys
-
+from apscheduler.schedulers.asyncio import AsyncIOScheduler
 from telegram.ext import ApplicationBuilder
 
 from remilia.log import (
@@ -8,13 +8,21 @@ from remilia.log import (
     LoguruHandler,
     default_format
 )
-from remilia.config import TOKEN
+from remilia.config import LOG_LEVEL, TOKEN
 
 
 logging.basicConfig(handlers=[LoguruHandler()], level=logging.DEBUG)
 
 logger.remove()
-logger.add(sys.stdout, level='INFO', diagnose=False, format=default_format)
+logger.add(sys.stdout, level=LOG_LEVEL, diagnose=False, format=default_format)
+
+
+scheduler = AsyncIOScheduler(timezone="Europe/Moscow")
+if not scheduler.running:
+    try:
+        scheduler.start()
+    except Exception as e:
+        logger.error(f"scheduler启动失败!\n{repr(e)}")
 
 
 from .plugins import (
@@ -32,7 +40,6 @@ from .plugins import (
 class run():
     app = ApplicationBuilder().token(TOKEN).build()
 
-
     start.run(app)
     block.run(app)
     cmd.run(app)
@@ -44,5 +51,4 @@ class run():
 
     chat.run(app)
 
-
     app.run_polling()
